# frozen_string_literal: true

require "byebug/commands/break"
require "byebug/commands/catch"
require "byebug/commands/condition"
require "byebug/commands/continue"
require "byebug/commands/debug"
require "byebug/commands/delete"
require "byebug/commands/disable"
require "byebug/commands/display"
require "byebug/commands/down"
require "byebug/commands/edit"
require "byebug/commands/enable"
require "byebug/commands/finish"
require "byebug/commands/frame"
require "byebug/commands/help"
require "byebug/commands/history"
require "byebug/commands/info"
require "byebug/commands/interrupt"
require "byebug/commands/irb"
require "byebug/commands/kill"
require "byebug/commands/list"
require "byebug/commands/method"
require "byebug/commands/next"
require "byebug/commands/pry"
require "byebug/commands/quit"
require "byebug/commands/restart"
require "byebug/commands/save"
require "byebug/commands/set"
require "byebug/commands/show"
require "byebug/commands/source"
require "byebug/commands/step"
require "byebug/commands/thread"
require "byebug/commands/tracevar"
require "byebug/commands/undisplay"
require "byebug/commands/untracevar"
require "byebug/commands/up"
require "byebug/commands/var"
require "byebug/commands/where"
